@@ -281,7 +281,7 @@ impl Error {
     }
 }
 
-impl<T: Display + Send + Sync + 'static> From<T> for Error {
+impl<T: Display + Send + Sync> From<T> for Error {
     fn from(e: T) -> Self {
         Self {
             message: e.to_string(),
