@@ -1,3 +1,5 @@
+use async_graphql_parser::types::BaseType;
+
 use crate::context::QueryPathNode;
 use crate::parser::types::VariableDefinition;
 use crate::validation::utils::is_valid_input_value;
@@ -12,13 +14,23 @@ impl<'a> Visitor<'a> for DefaultValuesOfCorrectType {
         ctx: &mut VisitorContext<'a>,
         variable_definition: &'a Positioned<VariableDefinition>,
     ) {
+        if let BaseType::Named(vtype_name) = &variable_definition.node.var_type.node.base {
+            if !ctx.registry.types.contains_key(vtype_name.as_str()) {
+                ctx.report_error(
+                    vec![variable_definition.pos],
+                    format!(r#"Unknown type "{}""#, vtype_name),
+                );
+                return;
+            }
+        }
+
         if let Some(value) = &variable_definition.node.default_value {
             if !variable_definition.node.var_type.node.nullable {
                 ctx.report_error(vec![variable_definition.pos],format!(
                     "Argument \"{}\" has type \"{}\" and is not nullable, so it can't have a default value",
                     variable_definition.node.name, variable_definition.node.var_type,
                 ));
-            } else if let Some(e) = is_valid_input_value(
+            } else if let Some(reason) = is_valid_input_value(
                 ctx.registry,
                 &variable_definition.node.var_type.to_string(),
                 &value.node,
@@ -27,10 +39,9 @@ impl<'a> Visitor<'a> for DefaultValuesOfCorrectType {
                     segment: QueryPathSegment::Name(&variable_definition.node.name.node),
                 },
             ) {
-                ctx.report_error_with_extensions(
+                ctx.report_error(
                     vec![variable_definition.pos],
-                    format!("Invalid default value for argument {}", e.message),
-                    e.extensions,
+                    format!("Invalid default value for argument: {}", reason),
                 )
             }
         }
